# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: intents.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'intents.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rintents.proto\x12\x0c\x61ristech.nlp\"\xad\x03\n\x06Intent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\r\n\x05topic\x18\x04 \x01(\t\x12)\n\x06inputs\x18\x05 \x03(\x0b\x32\x19.aristech.nlp.IntentInput\x12\x13\n\x0boutput_chat\x18\x06 \x03(\t\x12\x14\n\x0coutput_voice\x18\x07 \x03(\t\x12\x14\n\x0coutput_email\x18\x08 \x03(\t\x12*\n\nrelated_to\x18\t \x03(\x0b\x32\x16.aristech.nlp.Relation\x12\x11\n\tpublished\x18\n \x01(\x08\x12,\n\x04type\x18\x0b \x01(\x0e\x32\x1e.aristech.nlp.Intent.InputType\x12\"\n\x1a\x65xclude_output_from_search\x18\x0c \x01(\x08\x12\'\n\x08keywords\x18\r \x03(\x0b\x32\x15.aristech.nlp.Keyword\x12\x12\n\ncreator_id\x18\x0e \x01(\t\"*\n\tInputType\x12\x08\n\x04\x43HAT\x10\x00\x12\x08\n\x04MAIL\x10\x01\x12\t\n\x05VOICE\x10\x02\"*\n\x0bIntentInput\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\t\"<\n\x08Relation\x12\x0f\n\x07parents\x18\x01 \x03(\t\x12\x10\n\x08\x63hildren\x18\x02 \x03(\t\x12\r\n\x05peers\x18\x03 \x03(\t\",\n\x07Keyword\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\"=\n\x14UpdateContentRequest\x12%\n\x07intents\x18\x01 \x03(\x0b\x32\x14.aristech.nlp.Intent\"+\n\x15UpdateContentResponse\x12\x12\n\nintent_ids\x18\x01 \x03(\t\"6\n\x14RemoveContentRequest\x12\n\n\x02id\x18\x01 \x03(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x17\n\x15RemoveContentResponse\"\x9e\x01\n\x11GetContentRequest\x12\x0e\n\x06prompt\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x13\n\x0bnum_results\x18\x03 \x01(\x05\x12\x11\n\tthreshold\x18\x04 \x01(\x02\x12,\n\x07\x66ilters\x18\x05 \x03(\x0b\x32\x1b.aristech.nlp.ContentFilter\x12\x0f\n\x07\x63hat_id\x18\x07 \x01(\t\"W\n\x12GetContentResponse\x12\x30\n\x05items\x18\x01 \x03(\x0b\x32!.aristech.nlp.ContentResponseItem\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\t\"N\n\rContentFilter\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x10\n\x08operator\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x03(\t\"p\n\x13\x43ontentResponseItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12$\n\x06intent\x18\x03 \x01(\x0b\x32\x14.aristech.nlp.Intent\x12\x18\n\x10\x66\x61llback_message\x18\x04 \x01(\t\"\'\n\x11GetIntentsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\":\n\x12GetIntentsResponse\x12$\n\x06intent\x18\x01 \x03(\x0b\x32\x14.aristech.nlp.Intent\"s\n\x15GetScoreLimitsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\"\n\x1atest_sentences_upper_limit\x18\x02 \x03(\t\x12\"\n\x1atest_sentences_lower_limit\x18\x03 \x03(\t\"F\n\x16GetScoreLimitsResponse\x12\x15\n\rmin_threshold\x18\x01 \x01(\x02\x12\x15\n\rmax_threshold\x18\x02 \x01(\x02\x42\x08P\x01\xa2\x02\x03\x41TSb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'intents_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001\242\002\003ATS'
  _globals['_INTENT']._serialized_start=32
  _globals['_INTENT']._serialized_end=461
  _globals['_INTENT_INPUTTYPE']._serialized_start=419
  _globals['_INTENT_INPUTTYPE']._serialized_end=461
  _globals['_INTENTINPUT']._serialized_start=463
  _globals['_INTENTINPUT']._serialized_end=505
  _globals['_RELATION']._serialized_start=507
  _globals['_RELATION']._serialized_end=567
  _globals['_KEYWORD']._serialized_start=569
  _globals['_KEYWORD']._serialized_end=613
  _globals['_UPDATECONTENTREQUEST']._serialized_start=615
  _globals['_UPDATECONTENTREQUEST']._serialized_end=676
  _globals['_UPDATECONTENTRESPONSE']._serialized_start=678
  _globals['_UPDATECONTENTRESPONSE']._serialized_end=721
  _globals['_REMOVECONTENTREQUEST']._serialized_start=723
  _globals['_REMOVECONTENTREQUEST']._serialized_end=777
  _globals['_REMOVECONTENTRESPONSE']._serialized_start=779
  _globals['_REMOVECONTENTRESPONSE']._serialized_end=802
  _globals['_GETCONTENTREQUEST']._serialized_start=805
  _globals['_GETCONTENTREQUEST']._serialized_end=963
  _globals['_GETCONTENTRESPONSE']._serialized_start=965
  _globals['_GETCONTENTRESPONSE']._serialized_end=1052
  _globals['_CONTENTFILTER']._serialized_start=1054
  _globals['_CONTENTFILTER']._serialized_end=1132
  _globals['_CONTENTRESPONSEITEM']._serialized_start=1134
  _globals['_CONTENTRESPONSEITEM']._serialized_end=1246
  _globals['_GETINTENTSREQUEST']._serialized_start=1248
  _globals['_GETINTENTSREQUEST']._serialized_end=1287
  _globals['_GETINTENTSRESPONSE']._serialized_start=1289
  _globals['_GETINTENTSRESPONSE']._serialized_end=1347
  _globals['_GETSCORELIMITSREQUEST']._serialized_start=1349
  _globals['_GETSCORELIMITSREQUEST']._serialized_end=1464
  _globals['_GETSCORELIMITSRESPONSE']._serialized_start=1466
  _globals['_GETSCORELIMITSRESPONSE']._serialized_end=1536
# @@protoc_insertion_point(module_scope)
