# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nlp_server.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'nlp_server.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import projects_pb2 as projects__pb2
from . import intents_pb2 as intents__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10nlp_server.proto\x12\x0c\x61ristech.nlp\x1a\x0eprojects.proto\x1a\rintents.proto\"\x11\n\x0f\x46unctionRequest\"L\n\x08\x46unction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\targuments\x18\x04 \x03(\t\"b\n\x13RunFunctionsRequest\x12)\n\tfunctions\x18\x01 \x03(\x0b\x32\x16.aristech.nlp.Function\x12\r\n\x05input\x18\x02 \x01(\t\x12\x11\n\targuments\x18\x03 \x03(\t\"&\n\x14RunFunctionsResponse\x12\x0e\n\x06output\x18\x01 \x01(\t2\xa8\x08\n\tNLPServer\x12I\n\x0cGetFunctions\x12\x1d.aristech.nlp.FunctionRequest\x1a\x16.aristech.nlp.Function\"\x00\x30\x01\x12W\n\x0cRunFunctions\x12!.aristech.nlp.RunFunctionsRequest\x1a\".aristech.nlp.RunFunctionsResponse\"\x00\x12Z\n\rUpdateContent\x12\".aristech.nlp.UpdateContentRequest\x1a#.aristech.nlp.UpdateContentResponse\"\x00\x12Z\n\rRemoveContent\x12\".aristech.nlp.RemoveContentRequest\x1a#.aristech.nlp.RemoveContentResponse\"\x00\x12S\n\nGetContent\x12\x1f.aristech.nlp.GetContentRequest\x1a .aristech.nlp.GetContentResponse\"\x00\x30\x01\x12Q\n\nAddProject\x12\x1f.aristech.nlp.AddProjectRequest\x1a .aristech.nlp.AddProjectResponse\"\x00\x12Z\n\rRemoveProject\x12\".aristech.nlp.RemoveProjectRequest\x1a#.aristech.nlp.RemoveProjectResponse\"\x00\x12Z\n\rUpdateProject\x12\".aristech.nlp.UpdateProjectRequest\x1a#.aristech.nlp.UpdateProjectResponse\"\x00\x12J\n\x0bGetProjects\x12 .aristech.nlp.GetProjectsRequest\x1a\x15.aristech.nlp.Project\"\x00\x30\x01\x12S\n\nGetIntents\x12\x1f.aristech.nlp.GetIntentsRequest\x1a .aristech.nlp.GetIntentsResponse\"\x00\x30\x01\x12]\n\x0eGetScoreLimits\x12#.aristech.nlp.GetScoreLimitsRequest\x1a$.aristech.nlp.GetScoreLimitsResponse\"\x00\x12_\n\x12GetEmbeddingModels\x12\'.aristech.nlp.GetEmbeddingModelsRequest\x1a\x1c.aristech.nlp.EmbeddingModel\"\x00\x30\x01\x42\x08P\x01\xa2\x02\x03\x41TSb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nlp_server_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001\242\002\003ATS'
  _globals['_FUNCTIONREQUEST']._serialized_start=65
  _globals['_FUNCTIONREQUEST']._serialized_end=82
  _globals['_FUNCTION']._serialized_start=84
  _globals['_FUNCTION']._serialized_end=160
  _globals['_RUNFUNCTIONSREQUEST']._serialized_start=162
  _globals['_RUNFUNCTIONSREQUEST']._serialized_end=260
  _globals['_RUNFUNCTIONSRESPONSE']._serialized_start=262
  _globals['_RUNFUNCTIONSRESPONSE']._serialized_end=300
  _globals['_NLPSERVER']._serialized_start=303
  _globals['_NLPSERVER']._serialized_end=1367
# @@protoc_insertion_point(module_scope)
